@@ -8,6 +8,7 @@ import logging
 import os
 import shutil
 import subprocess
+import sys
 import tempfile
 import time
 import unittest
@@ -24,8 +25,8 @@ from selenium.webdriver.support.ui import WebDriverWait
 gi.require_version('Gdk', '4.0')
 gi.require_version('GdkPixbuf', '2.0')
 from gi.repository import Gdk, GdkPixbuf, Gio, GLib
-
 from kicker.favoritetest import start_kactivitymanagerd
+from notificationstest.jobnotificationinterface import JobNotificationControlInterface
 
 WIDGET_ID: Final = "org.kde.plasma.notifications"
 KDE_VERSION: Final = 6
@@ -82,7 +83,7 @@ class NotificationsTest(unittest.TestCase):
             "LC_ALL": "en_US.UTF-8",
             "QT_LOGGING_RULES": "kf.notification*.debug=true;org.kde.plasma.notificationmanager.debug=true",
         })
-        cls.driver = webdriver.Remote(command_executor='http://127.0.0.1:4723', options=options)
+        cls.driver = webdriver.Remote(command_executor=f'http://127.0.0.1:{os.getenv("FLASK_PORT", "4723")}', options=options)
 
         cls.notification_proxy = Gio.DBusProxy.new_for_bus_sync(Gio.BusType.SESSION, 0, None, BUS_NAME, OBJECT_PATH, IFACE_NAME)
 
@@ -101,12 +102,6 @@ class NotificationsTest(unittest.TestCase):
         subprocess.check_call([f"kquitapp{KDE_VERSION}", "plasmawindowed"])
         cls.kactivitymanagerd.kill()
         cls.kactivitymanagerd.wait(10)
-        for _ in range(10):
-            try:
-                subprocess.check_call(["pidof", "plasmawindowed"])
-            except subprocess.CalledProcessError:
-                break
-            time.sleep(1)
         cls.driver.quit()
 
     def close_notifications(self) -> None:
@@ -177,7 +172,7 @@ class NotificationsTest(unittest.TestCase):
                         pixbuf.get_pixels(),
                     ]),
                 },
-                "timeout": 10 * 1000,
+                "timeout": 30 * 1000,
             })
             wait.until(EC.presence_of_element_located((AppiumBy.NAME, summary + str(color))))
             partial_pixbuf.fill(color)
@@ -239,7 +234,8 @@ class NotificationsTest(unittest.TestCase):
                 case "NotificationClosed":
                     params_3 = parameters.unpack()
                     notification_closed = True
-                    loop.quit()
+            if activation_token and action_invoked and notification_closed:
+                loop.quit()
 
         connection_id = self.notification_proxy.connect("g-signal", notification_signal_handler)
         self.addCleanup(lambda: self.notification_proxy.disconnect(connection_id))
@@ -248,6 +244,7 @@ class NotificationsTest(unittest.TestCase):
             "app_name": "Appium Test",
             "body": "A notification with actions",
             "actions": ["action1", "FooAction", "action2", "BarAction"],
+            "timeout": 30 * 1000,
         })
         self.driver.find_element(AppiumBy.NAME, "BarAction")
         element = self.driver.find_element(AppiumBy.NAME, "FooAction")
@@ -261,7 +258,7 @@ class NotificationsTest(unittest.TestCase):
         self.assertTrue(notification_closed)
         self.assertEqual(params_3[0], notification_id)
         self.assertEqual(params_3[1], 3)  # reason: Revoked
-        self.assertFalse(element.is_displayed())
+        WebDriverWait(self.driver, 5).until_not(lambda _: element.is_displayed())
 
     def test_5_inline_reply(self) -> None:
         """
@@ -287,6 +284,7 @@ class NotificationsTest(unittest.TestCase):
             "app_name": "Appium Test",
             "body": "A notification with actions 1",
             "actions": ["inline-reply", ""],  # Use the default label
+            "timeout": 30 * 1000,
         })
         reply_text = "this is a reply"
         self.driver.find_element(AppiumBy.NAME, "begin reply").click()
@@ -308,6 +306,7 @@ class NotificationsTest(unittest.TestCase):
                 "x-kde-reply-submit-button-text": GLib.Variant("s", "Reeply"),  # Use a custom label
                 "x-kde-reply-placeholder-text": GLib.Variant("s", "A placeholder"),  # Use a custom placeholder
             },
+            "timeout": 30 * 1000,
         })
         reply_text = "this is another reply"
         self.driver.find_element(AppiumBy.NAME, "begin reply").click()
@@ -325,6 +324,7 @@ class NotificationsTest(unittest.TestCase):
             "app_name": "Appium Test",
             "body": "A notification with actions 3",
             "actions": ["inline-reply", "Replyy", "foo", "Foo", "bar", "Bar"],  # Click to show the text field
+            "timeout": 30 * 1000,
         })
         self.driver.find_element(AppiumBy.NAME, "Foo")
         self.driver.find_element(AppiumBy.NAME, "Bar")
@@ -359,7 +359,7 @@ class NotificationsTest(unittest.TestCase):
                 "hints": {
                     "x-kde-urls": GLib.Variant("as", url_list),
                 },
-                "timeout": 10 * 1000,
+                "timeout": 30 * 1000,
             })
 
             self.driver.find_element(AppiumBy.NAME, "More Options…")
@@ -378,7 +378,46 @@ class NotificationsTest(unittest.TestCase):
             WebDriverWait(self.driver, 10).until(match_image)
             self.close_notifications()
 
-    def test_7_do_not_disturb(self) -> None:
+    def test_7_job_notification(self) -> None:
+        """
+        https://bugs.kde.org/show_bug.cgi?id=501991
+        """
+        try:
+            from PySide6.QtCore import QObject
+        except ModuleNotFoundError:
+            self.skipTest("PySide is not available")
+
+        asan_env = os.environ.copy()
+        asan_env["LD_PRELOAD"] = subprocess.check_output(["gcc", "-print-file-name=libasan.so"]).strip().decode(encoding="utf-8")
+        proc = subprocess.Popen(["python3", os.path.join(os.path.dirname(os.path.abspath(__file__)), "notificationstest", "jobnotification.py")], stdout=sys.stderr, stderr=sys.stderr, env=asan_env)
+        self.addCleanup(proc.kill)
+        self.driver.find_element(AppiumBy.NAME, "10%")
+        self.driver.find_element(AppiumBy.XPATH, "//notification[contains(@description, '1 file')]")
+        self.driver.find_element(AppiumBy.NAME, "Pause").click()
+        self.driver.find_element(AppiumBy.NAME, "Resume").click()
+        self.driver.find_element(AppiumBy.XPATH, "//button[@name='Details' and contains(@accessibility-id, 'NotificationPopup')]").click()  # Expand details in the popup
+
+        # Change progress to 20%
+        session_bus: Gio.DBusConnection = Gio.bus_get_sync(Gio.BusType.SESSION)
+        session_bus.call_sync(JobNotificationControlInterface.BUS_NAME, JobNotificationControlInterface.OBJECT_PATH, JobNotificationControlInterface.BUS_NAME, "SetProcessedAmount", GLib.Variant("(t)", [1024 * 1024 * 2]), None, Gio.DBusSendMessageFlags.NONE, 1000)
+        self.driver.find_element(AppiumBy.NAME, "20%")
+        self.driver.find_element(AppiumBy.NAME, "8 s remaining")
+        self.driver.find_element(AppiumBy.NAME, "1.0 MiB/s")
+        self.driver.find_element(AppiumBy.XPATH, "//chart[contains(@accessibility-id, 'LineChart')]")
+
+        # Change progress to 50%
+        session_bus.call_sync(JobNotificationControlInterface.BUS_NAME, JobNotificationControlInterface.OBJECT_PATH, JobNotificationControlInterface.BUS_NAME, "SetProcessedAmount", GLib.Variant("(t)", [1024 * 1024 * 5]), None, Gio.DBusSendMessageFlags.NONE, 1000)
+        self.driver.find_element(AppiumBy.NAME, "50%")
+        self.driver.find_element(AppiumBy.NAME, "2 s remaining")
+        self.driver.find_element(AppiumBy.NAME, "3.0 MiB/s")
+
+        # Change progress to 100%. The job should emit finished signal.
+        session_bus.call_sync(JobNotificationControlInterface.BUS_NAME, JobNotificationControlInterface.OBJECT_PATH, JobNotificationControlInterface.BUS_NAME, "SetProcessedAmount", GLib.Variant("(t)", [1024 * 1024 * 10]), None, Gio.DBusSendMessageFlags.NONE, 1000)
+        self.driver.find_element(AppiumBy.NAME, "Job Finished")
+        self.driver.find_element(AppiumBy.XPATH, "//notification[contains(@description, 'file:///home/foobar/test.txt')]")
+        proc.wait(10)
+
+    def test_8_do_not_disturb(self) -> None:
         """
         Suppress inhibited notifications after "Do not disturb" is turned off, and show a summary for unread inhibited notifications.
         """
@@ -396,7 +435,7 @@ class NotificationsTest(unittest.TestCase):
                 "timeout": 60 * 1000,
             })
         title = self.driver.find_element(AppiumBy.XPATH, f"//heading[starts-with(@name, '{summary}') and contains(@accessibility-id, 'FullRepresentation')]")
-        self.assertRaises(NoSuchElementException, self.driver.find_element, AppiumBy.XPATH, f"//notification[starts-with(@name, '{summary}')]")
+        self.assertRaises((NoSuchElementException, WebDriverException), self.driver.find_element, AppiumBy.XPATH, f"//notification[starts-with(@name, '{summary}')]")
 
         dnd_button.click()
         self.driver.find_element(AppiumBy.XPATH, "//notification[@name='Unread Notifications' and @description='2 notifications were received while Do Not Disturb was active.  from Notification Manager']")
@@ -408,6 +447,6 @@ class NotificationsTest(unittest.TestCase):
 
 
 if __name__ == '__main__':
-    assert "USE_CUSTOM_BUS" in os.environ or subprocess.call(["pidof", "plasmashell"]) != 0
+    assert "USE_CUSTOM_BUS" in os.environ or subprocess.call(["pidof", "plasmashell"]) != 0 or "KDECI_BUILD" in os.environ, "plasmashell should not be running"
     logging.getLogger().setLevel(logging.INFO)
     unittest.main(failfast=True)
