@@ -17,8 +17,6 @@
 #include <QRegularExpression>
 #include <QTimeZone>
 
-using namespace Qt::StringLiterals;
-
 WeatherData::WeatherData()
     : stationLatitude(qQNaN())
     , stationLongitude(qQNaN())
@@ -492,7 +490,7 @@ bool EnvCanadaIon::updateIonSource(const QString &source)
 void EnvCanadaIon::getXMLSetup()
 {
     // If network is down, we need to spin and wait
-    const QUrl url(QStringLiteral("https://dd.weather.gc.ca/today/citypage_weather/siteList.xml"));
+    const QUrl url(QStringLiteral("https://dd.weather.gc.ca/citypage_weather/xml/siteList.xml"));
     qCDebug(IONENGINE_ENVCAN) << "Fetching station list:" << url;
 
     KIO::TransferJob *getJob = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);
@@ -518,7 +516,7 @@ void EnvCanadaIon::getXMLData(const QString &source)
     const XMLMapInfo &place = m_places[dataKey];
 
     const QUrl url(QStringLiteral("https://dd.weather.gc.ca/citypage_weather/xml/%1/%2_e.xml").arg(place.territoryName, place.cityCode));
-    qCDebug(IONENGINE_ENVCAN) << "Fetching legacy weather URL:" << url;
+    qCDebug(IONENGINE_ENVCAN) << "Fetching weather URL:" << url;
 
     if (place.territoryName.isEmpty() && place.cityCode.isEmpty()) {
         setData(source, QStringLiteral("validate"), QStringLiteral("envcan|malformed"));
@@ -534,51 +532,6 @@ void EnvCanadaIon::getXMLData(const QString &source)
     connect(getJob, &KJob::result, this, &EnvCanadaIon::slotJobFinished);
 }
 
-// The weather URL has a dynamic name and path depending on its timestamp:
-// https://dd.weather.gc.ca/today/citypage_weather/{PROV}/{HH}/{YYYYMMDD}T{HHmmss.sss}Z_MSC_CitypageWeather_{SiteCode}_en.xml
-// This method is called iteratively 3 times to get the URL and then the weather report
-void EnvCanadaIon::getWeatherData(const QString &source)
-{
-    WeatherData::UrlInfo &info = m_weatherData[source].urlInfo;
-
-    info.requests++;
-    if (info.requests > 3) {
-        qCWarning(IONENGINE_ENVCAN) << "Too many requests to find the weather URL";
-        return;
-    }
-
-    // We get the place info from the stations list
-    if (info.cityCode.isEmpty()) {
-        QString dataKey = source;
-        dataKey.remove(QStringLiteral("envcan|weather|"));
-        const XMLMapInfo &place = m_places[dataKey];
-
-        info.province = place.territoryName;
-        info.cityCode = place.cityCode;
-    }
-
-    // 1. Base URL, on the territory dir, to get the list of hours
-    QString url = u"https://dd.weather.gc.ca/today/citypage_weather/%1/"_s.arg(info.province);
-    // 2. When we know the hour folder, we check for the weather report files
-    if (!info.hours.isEmpty()) {
-        url += info.hours.at(info.hourIndex) + u"/";
-    }
-    // 3. Now we have the full information to compose the URL
-    if (!info.fileName.isEmpty()) {
-        url += info.fileName;
-    }
-
-    qCDebug(IONENGINE_ENVCAN) << "Fetching weather URL:" << url;
-
-    KIO::TransferJob *getJob = KIO::get(QUrl(url), KIO::Reload, KIO::HideProgressInfo);
-
-    m_jobXml.insert(getJob, new QXmlStreamReader);
-    m_jobList.insert(getJob, source);
-
-    connect(getJob, &KIO::TransferJob::data, this, &EnvCanadaIon::slotDataArrived);
-    connect(getJob, &KJob::result, this, &EnvCanadaIon::slotJobFinished);
-}
-
 void EnvCanadaIon::setup_slotDataArrived(KIO::Job *job, const QByteArray &data)
 {
     Q_UNUSED(job)
@@ -597,13 +550,7 @@ void EnvCanadaIon::slotDataArrived(KIO::Job *job, const QByteArray &data)
         return;
     }
 
-    // Remove the HTML doctype line from XML parsing
-    if (data.startsWith("<!DOCTYPE"_ba)) {
-        int newLinePos = data.indexOf('\n');
-        m_jobXml[job]->addData(QByteArrayView(data).slice(newLinePos + 1));
-        return;
-    }
-
+    // Send to xml.
     m_jobXml[job]->addData(data);
 }
 
@@ -613,16 +560,10 @@ void EnvCanadaIon::slotJobFinished(KJob *job)
     const QString source = m_jobList.value(job);
     setData(source, Data());
     QXmlStreamReader *reader = m_jobXml.value(job);
-    if (!job->error() && reader) {
+    if (reader) {
         readXMLData(m_jobList[job], *reader);
     }
 
-    if (job->error() == KIO::ERR_DOES_NOT_EXIST || qobject_cast<KIO::TransferJob *>(job)->isErrorPage()) {
-        qCDebug(IONENGINE_ENVCAN) << "Legacy page not found. Falling back to new API";
-        m_weatherData[source].urlInfo = WeatherData::UrlInfo();
-        getWeatherData(source);
-    }
-
     m_jobList.remove(job);
     delete m_jobXml[job];
     m_jobXml.remove(job);
@@ -662,7 +603,7 @@ bool EnvCanadaIon::readXMLSetup()
         if (m_xmlSetup.isStartElement()) {
             // XML ID code to match filename
             if (elementName == QLatin1String("site")) {
-                code = m_xmlSetup.attributes().value(QStringLiteral("code")).toString();
+                code = m_xmlSetup.attributes().value(u"code").toString();
             }
 
             if (elementName == QLatin1String("nameEn")) {
@@ -745,11 +686,6 @@ bool EnvCanadaIon::readXMLData(const QString &source, QXmlStreamReader &xml)
         if (xml.isStartElement()) {
             if (xml.name() == QLatin1String("siteData")) {
                 parseWeatherSite(data, xml);
-            } else if (xml.name() == QLatin1String("html")) {
-                auto &urlInfo = m_weatherData[source].urlInfo;
-                parseDirListing(urlInfo, xml);
-                getWeatherData(source);
-                return !xml.hasError();
             } else {
                 parseUnknownElement(xml);
             }
@@ -797,53 +733,6 @@ bool EnvCanadaIon::readXMLData(const QString &source, QXmlStreamReader &xml)
     return !xml.error();
 }
 
-void EnvCanadaIon::parseDirListing(WeatherData::UrlInfo &info, QXmlStreamReader &xml)
-{
-    const bool expectingFileNames = !info.hours.isEmpty();
-
-    while (!xml.atEnd()) {
-        xml.readNext();
-
-        // We are parsing a directory listing with files or folders as hyperlinks
-        if (xml.isStartElement() && xml.name() == "a"_L1) {
-            QString item = xml.attributes().value(u"href").toString().trimmed();
-
-            // Check for hour folders
-            if (!expectingFileNames && item.endsWith('/'_L1)) {
-                item.slice(0, item.length() - 1);
-
-                bool isHour = false;
-                item.toInt(&isHour);
-                if (isHour) {
-                    info.hours.prepend(item);
-                }
-                continue;
-            }
-
-            // Check just for files that match our city code en English language
-            if (item.endsWith(u"%1_en.xml"_s.arg(info.cityCode))) {
-                info.fileName = item;
-            }
-        }
-    }
-
-    // Sort hours in reverse order (more recent first)
-    if (!expectingFileNames && !info.hours.isEmpty()) {
-        std::sort(info.hours.begin(), info.hours.end(), [](const auto &a, const auto &b) {
-            return a.toInt() > b.toInt();
-        });
-    }
-
-    // If we didn't find the filename in the current hour folder
-    // set up a new requests to search it on the previous one
-    if (expectingFileNames && info.fileName.isEmpty()) {
-        if (info.hourIndex < info.hours.count()) {
-            info.hourIndex++;
-            info.requests--;
-        }
-    }
-}
-
 void EnvCanadaIon::parseFloat(float &value, QXmlStreamReader &xml)
 {
     bool ok = false;
@@ -858,9 +747,9 @@ void EnvCanadaIon::parseDateTime(WeatherData &data, QXmlStreamReader &xml, Weath
     Q_ASSERT(xml.isStartElement() && xml.name() == QLatin1String("dateTime"));
 
     // What kind of date info is this?
-    const QString dateType = xml.attributes().value(QStringLiteral("name")).toString();
-    const QString dateZone = xml.attributes().value(QStringLiteral("zone")).toString();
-    const QString dateUtcOffset = xml.attributes().value(QStringLiteral("UTCOffset")).toString();
+    const QString dateType = xml.attributes().value(u"name").toString();
+    const QString dateZone = xml.attributes().value(u"zone").toString();
+    const QString dateUtcOffset = xml.attributes().value(u"UTCOffset").toString();
 
     QString selectTimeStamp;
 
@@ -976,7 +865,7 @@ void EnvCanadaIon::parseWindInfo(WeatherData &data, QXmlStreamReader &xml)
             } else if (elementName == QLatin1String("direction")) {
                 data.windDirection = xml.readElementText();
             } else if (elementName == QLatin1String("bearing")) {
-                data.windDegrees = xml.attributes().value(QStringLiteral("degrees")).toString();
+                data.windDegrees = xml.attributes().value(u"degrees").toString();
             } else {
                 parseUnknownElement(xml);
             }
@@ -1033,10 +922,9 @@ void EnvCanadaIon::parseConditions(WeatherData &data, QXmlStreamReader &xml)
 
         if (xml.isStartElement()) {
             if (elementName == QLatin1String("station")) {
-                data.stationID = xml.attributes().value(QStringLiteral("code")).toString();
-                data.stationLatitude = parseCoordinate(xml.attributes().value(QStringLiteral("lat")).toString());
-                data.stationLongitude = parseCoordinate(xml.attributes().value(QStringLiteral("lon")).toString());
-
+                data.stationID = xml.attributes().value(u"code").toString();
+                data.stationLatitude = parseCoordinate(xml.attributes().value(u"lat").toString());
+                data.stationLongitude = parseCoordinate(xml.attributes().value(u"lon").toString());
             } else if (elementName == QLatin1String("dateTime")) {
                 parseDateTime(data, xml);
             } else if (elementName == QLatin1String("condition")) {
@@ -1053,7 +941,7 @@ void EnvCanadaIon::parseConditions(WeatherData &data, QXmlStreamReader &xml)
                 // prevent N/A text to result in 0.0 value
                 parseFloat(data.windchill, xml);
             } else if (elementName == QLatin1String("pressure")) {
-                data.pressureTendency = xml.attributes().value(QStringLiteral("tendency")).toString();
+                data.pressureTendency = xml.attributes().value(u"tendency").toString();
                 if (data.pressureTendency.isEmpty()) {
                     data.pressureTendency = QStringLiteral("steady");
                 }
@@ -1077,7 +965,7 @@ void EnvCanadaIon::parseWarnings(WeatherData &data, QXmlStreamReader &xml)
     WeatherData::WeatherEvent *warning = new WeatherData::WeatherEvent;
 
     Q_ASSERT(xml.isStartElement() && xml.name() == QLatin1String("warnings"));
-    QString eventURL = xml.attributes().value(QStringLiteral("url")).toString();
+    QString eventURL = xml.attributes().value(u"url").toString();
 
     // envcan provides three type of events: 'warning', 'watch' and 'advisory'
     const auto mapToPriority = [](const QString &type) {
@@ -1109,8 +997,8 @@ void EnvCanadaIon::parseWarnings(WeatherData &data, QXmlStreamReader &xml)
             } else if (elementName == QLatin1String("event")) {
                 // Append new event to list.
                 warning->url = eventURL;
-                warning->description = xml.attributes().value(QStringLiteral("description")).toString();
-                warning->priority = mapToPriority(xml.attributes().value(QStringLiteral("type")).toString());
+                warning->description = xml.attributes().value(u"description").toString();
+                warning->priority = mapToPriority(xml.attributes().value(u"type").toString());
             } else {
                 if (xml.name() != QLatin1String("dateTime")) {
                     parseUnknownElement(xml);
@@ -1167,10 +1055,10 @@ void EnvCanadaIon::parseRegionalNormals(WeatherData &data, QXmlStreamReader &xml
         if (xml.isStartElement()) {
             if (elementName == QLatin1String("textSummary")) {
                 xml.readElementText();
-            } else if (elementName == QLatin1String("temperature") && xml.attributes().value(QStringLiteral("class")) == QLatin1String("high")) {
+            } else if (elementName == QLatin1String("temperature") && xml.attributes().value(u"class") == QLatin1String("high")) {
                 // prevent N/A text to result in 0.0 value
                 parseFloat(data.normalHigh, xml);
-            } else if (elementName == QLatin1String("temperature") && xml.attributes().value(QStringLiteral("class")) == QLatin1String("low")) {
+            } else if (elementName == QLatin1String("temperature") && xml.attributes().value(u"class") == QLatin1String("low")) {
                 // prevent N/A text to result in 0.0 value
                 parseFloat(data.normalLow, xml);
             }
@@ -1194,7 +1082,7 @@ void EnvCanadaIon::parseForecast(WeatherData &data, QXmlStreamReader &xml, Weath
 
         if (xml.isStartElement()) {
             if (elementName == QLatin1String("period")) {
-                forecast->forecastPeriod = xml.attributes().value(QStringLiteral("textForecastName")).toString();
+                forecast->forecastPeriod = xml.attributes().value(u"textForecastName").toString();
             } else if (elementName == QLatin1String("textSummary")) {
                 forecast->forecastSummary = xml.readElementText();
             } else if (elementName == QLatin1String("abbreviatedForecast")) {
@@ -1206,7 +1094,7 @@ void EnvCanadaIon::parseForecast(WeatherData &data, QXmlStreamReader &xml, Weath
             } else if (elementName == QLatin1String("precipitation")) {
                 parsePrecipitationForecast(forecast, xml);
             } else if (elementName == QLatin1String("uv")) {
-                data.UVRating = xml.attributes().value(QStringLiteral("category")).toString();
+                data.UVRating = xml.attributes().value(u"category").toString();
                 parseUVIndex(data, xml);
                 // else if (elementName == QLatin1String("frost")) { FIXME: Wait until winter to see what this looks like.
                 //  parseFrost(xml, forecast);
@@ -1311,9 +1199,9 @@ void EnvCanadaIon::parseForecastTemperatures(WeatherData::ForecastInfo *forecast
         }
 
         if (xml.isStartElement()) {
-            if (elementName == QLatin1String("temperature") && xml.attributes().value(QStringLiteral("class")) == QLatin1String("low")) {
+            if (elementName == QLatin1String("temperature") && xml.attributes().value(u"class") == QLatin1String("low")) {
                 parseFloat(forecast->tempLow, xml);
-            } else if (elementName == QLatin1String("temperature") && xml.attributes().value(QStringLiteral("class")) == QLatin1String("high")) {
+            } else if (elementName == QLatin1String("temperature") && xml.attributes().value(u"class") == QLatin1String("high")) {
                 parseFloat(forecast->tempHigh, xml);
             } else if (elementName == QLatin1String("textSummary")) {
                 xml.readElementText();
@@ -1407,12 +1295,12 @@ void EnvCanadaIon::parseYesterdayWeather(WeatherData &data, QXmlStreamReader &xm
         const auto elementName = xml.name();
 
         if (xml.isStartElement()) {
-            if (elementName == QLatin1String("temperature") && xml.attributes().value(QStringLiteral("class")) == QLatin1String("high")) {
+            if (elementName == QLatin1String("temperature") && xml.attributes().value(u"class") == QLatin1String("high")) {
                 parseFloat(data.prevHigh, xml);
-            } else if (elementName == QLatin1String("temperature") && xml.attributes().value(QStringLiteral("class")) == QLatin1String("low")) {
+            } else if (elementName == QLatin1String("temperature") && xml.attributes().value(u"class") == QLatin1String("low")) {
                 parseFloat(data.prevLow, xml);
             } else if (elementName == QLatin1String("precip")) {
-                data.prevPrecipType = xml.attributes().value(QStringLiteral("units")).toString();
+                data.prevPrecipType = xml.attributes().value(u"units").toString();
                 if (data.prevPrecipType.isEmpty()) {
                     data.prevPrecipType = QString::number(KUnitConversion::NoUnit);
                 }
@@ -1436,13 +1324,13 @@ void EnvCanadaIon::parseWeatherRecords(WeatherData &data, QXmlStreamReader &xml)
         }
 
         if (xml.isStartElement()) {
-            if (elementName == QLatin1String("temperature") && xml.attributes().value(QStringLiteral("class")) == QLatin1String("extremeMax")) {
+            if (elementName == QLatin1String("temperature") && xml.attributes().value(u"class") == QLatin1String("extremeMax")) {
                 parseFloat(data.recordHigh, xml);
-            } else if (elementName == QLatin1String("temperature") && xml.attributes().value(QStringLiteral("class")) == QLatin1String("extremeMin")) {
+            } else if (elementName == QLatin1String("temperature") && xml.attributes().value(u"class") == QLatin1String("extremeMin")) {
                 parseFloat(data.recordLow, xml);
-            } else if (elementName == QLatin1String("precipitation") && xml.attributes().value(QStringLiteral("class")) == QLatin1String("extremeRainfall")) {
+            } else if (elementName == QLatin1String("precipitation") && xml.attributes().value(u"class") == QLatin1String("extremeRainfall")) {
                 parseFloat(data.recordRain, xml);
-            } else if (elementName == QLatin1String("precipitation") && xml.attributes().value(QStringLiteral("class")) == QLatin1String("extremeSnowfall")) {
+            } else if (elementName == QLatin1String("precipitation") && xml.attributes().value(u"class") == QLatin1String("extremeSnowfall")) {
                 parseFloat(data.recordSnow, xml);
             }
         }
@@ -1623,7 +1511,7 @@ void EnvCanadaIon::updateWeather(const QString &source)
         QString forecastPeriod = forecastInfo->forecastPeriod;
         // Indicate whether the first forcast is a nightly one
         if (i == 0) {
-            data.insert(QStringLiteral("Forecast Starts at Night"), forecastPeriod.contains(QStringLiteral("night")));
+            data.insert(QStringLiteral("Forecast Starts at Night"), forecastPeriod.contains(u"night"));
         }
 
         if (forecastPeriod.isEmpty()) {
