@@ -130,6 +130,9 @@ void NotificationFilterProxyModel::setWhitelistedNotifyRcNames(const QStringList
 
 bool NotificationFilterProxyModel::filterAcceptsRow(int source_row, const QModelIndex &source_parent) const
 {
+    if (!sourceModel()->hasIndex(source_row, 0, source_parent)) {
+        return false;
+    }
     const QModelIndex sourceIdx = sourceModel()->index(source_row, 0, source_parent);
 
     const bool expired = sourceIdx.data(Notifications::ExpiredRole).toBool();
@@ -191,12 +194,8 @@ bool NotificationFilterProxyModel::filterAcceptsRow(int source_row, const QModel
         }
     }
 
-    // Normal Do Not Disturb filtering
-    if (!m_showAddedDuringInhibition) {
-        // Show critical notifications even in Do Not Disturb
-        if (!m_urgencies.testFlag(urgency) && sourceIdx.data(Notifications::WasAddedDuringInhibitionRole).toBool()) {
-            return false;
-        }
+    if (!m_showAddedDuringInhibition && sourceIdx.data(Notifications::WasAddedDuringInhibitionRole).toBool()) {
+        return false;
     }
 
     return true;
