@@ -8,9 +8,14 @@
 
 #include <QConcatenateTablesProxyModel>
 #include <QDebug>
+#include <QFile>
 #include <QMetaEnum>
+#include <canberra.h>
 #include <memory>
 
+#include <KConfig>
+#include <KConfigGroup>
+#include <KConfigWatcher>
 #include <KDescendantsProxyModel>
 #include <KLocalizedString>
 #include <KNotification>
@@ -76,6 +81,7 @@ public:
     int expiredNotificationsCount = 0;
 
     int unreadNotificationsCount = 0;
+    int dismissedResidentNotificationsCount = 0;
 
     int activeJobsCount = 0;
     int jobsPercentage = 0;
@@ -96,7 +102,7 @@ public:
     NotificationGroupingProxyModel *groupingModel = nullptr;
     NotificationGroupCollapsingProxyModel *groupCollapsingModel = nullptr;
     KDescendantsProxyModel *flattenModel = nullptr;
-
+    ca_context *canberraContext = nullptr;
     LimitedRowCountProxyModel *limiterModel = nullptr;
 
 private:
@@ -204,7 +210,8 @@ void Notifications::Private::initProxyModels()
             Q_UNUSED(topLeft);
             Q_UNUSED(bottomRight);
             if (roles.isEmpty() || roles.contains(Notifications::UpdatedRole) || roles.contains(Notifications::ExpiredRole)
-                || roles.contains(Notifications::JobStateRole) || roles.contains(Notifications::PercentageRole) || roles.contains(Notifications::ReadRole)) {
+                || roles.contains(Notifications::JobStateRole) || roles.contains(Notifications::PercentageRole) || roles.contains(Notifications::ReadRole)
+                || roles.contains(Notifications::ResidentRole) || roles.contains(Notifications::DismissedRole)) {
                 updateCount();
             }
         });
@@ -258,6 +265,7 @@ void Notifications::Private::updateCount()
     int active = 0;
     int expired = 0;
     int unread = 0;
+    int dismissedResident = 0;
 
     int jobs = 0;
     int totalPercentage = 0;
@@ -268,7 +276,8 @@ void Notifications::Private::updateCount()
     for (int i = 0; i < filterModel->rowCount(); ++i) {
         const QModelIndex idx = filterModel->index(i, 0);
 
-        if (idx.data(Notifications::ExpiredRole).toBool() || idx.data(Notifications::WasAddedDuringInhibitionRole).toBool()) {
+        const bool isExpired = idx.data(Notifications::ExpiredRole).toBool();
+        if (isExpired || idx.data(Notifications::WasAddedDuringInhibitionRole).toBool()) {
             ++expired;
         } else {
             ++active;
@@ -286,6 +295,10 @@ void Notifications::Private::updateCount()
             }
         }
 
+        if (!isExpired && idx.data(Notifications::ResidentRole).toBool() && idx.data(Notifications::DismissedRole).toBool()) {
+            ++dismissedResident;
+        }
+
         if (idx.data(Notifications::TypeRole).toInt() == Notifications::JobType) {
             if (idx.data(Notifications::JobStateRole).toInt() != Notifications::JobStateStopped) {
                 ++jobs;
@@ -307,6 +320,10 @@ void Notifications::Private::updateCount()
         unreadNotificationsCount = unread;
         Q_EMIT q->unreadNotificationsCountChanged();
     }
+    if (dismissedResidentNotificationsCount != dismissedResident) {
+        dismissedResidentNotificationsCount = dismissedResident;
+        Q_EMIT q->dismissedResidentNotificationsCountChanged();
+    }
     if (activeJobsCount != jobs) {
         activeJobsCount = jobs;
         Q_EMIT q->activeJobsCountChanged();
@@ -670,6 +687,11 @@ int Notifications::unreadNotificationsCount() const
     return d->unreadNotificationsCount;
 }
 
+int Notifications::dismissedResidentNotificationsCount() const
+{
+    return d->dismissedResidentNotificationsCount;
+}
+
 int Notifications::activeJobsCount() const
 {
     return d->activeJobsCount;
@@ -860,8 +882,11 @@ void Notifications::showInhibitionSummary()
     }
 
     KNotification::event(u"inhibitionSummary"_s,
-                         i18nc("@title", "Unread Notifications"),
-                         i18nc("@info", "%1 notifications were received while Do Not Disturb was active.", QString::number(inhibited)),
+                         i18ncp("@title", "Unread Notification", "Unread Notifications", inhibited),
+                         i18ncp("@info",
+                                "%1 notification was received while Do Not Disturb was active.",
+                                "%1 notifications were received while Do Not Disturb was active.",
+                                inhibited),
                          u"preferences-desktop-notification-bell"_s,
                          KNotification::CloseOnTimeout,
                          u"libnotificationmanager"_s);
@@ -897,4 +922,65 @@ QHash<int, QByteArray> Notifications::roleNames() const
     return Utils::roleNames();
 }
 
+void Notifications::playSoundHint(const QModelIndex &idx) const
+{
+    auto hints = data(idx, Notifications::HintsRole).toMap();
+    auto soundFilePath = hints.value(QStringLiteral("sound-file")).toString();
+    auto soundName = hints.value(QStringLiteral("sound-name")).toString();
+    auto isSuppressSound = hints.value(QStringLiteral("suppress-sound")).toBool();
+    auto desktopFile = data(idx, Notifications::DesktopEntryRole).toString();
+    auto appName = data(idx, Notifications::ApplicationNameRole).toString();
+
+    if (isSuppressSound || (soundName.isEmpty() && soundFilePath.isEmpty())) {
+        return;
+    }
+
+    if (!d->canberraContext) {
+        const int ret = ca_context_create(&d->canberraContext);
+        if (ret != CA_SUCCESS) {
+            qCWarning(NOTIFICATIONMANAGER)
+                << "Failed to initialize canberra context for audio notification:"
+                << ca_strerror(ret);
+            d->canberraContext = nullptr;
+            return;
+        }
+    }
+
+    ca_proplist *props = nullptr;
+    ca_proplist_create(&props);
+
+    const auto config = KSharedConfig::openConfig(QStringLiteral("kdeglobals"));
+    const KConfigGroup soundGroup = config->group(QStringLiteral("Sounds"));
+    const auto soundTheme =
+        soundGroup.readEntry("Theme", QStringLiteral("ocean"));
+
+    if (!soundName.isEmpty()) {
+        ca_proplist_sets(props, CA_PROP_EVENT_ID, soundName.toLatin1().constData());
+    }
+    if (!soundFilePath.isEmpty()) {
+        ca_proplist_sets(props, CA_PROP_MEDIA_FILENAME,
+                       QFile::encodeName(soundFilePath).constData());
+    }
+    ca_proplist_sets(props, CA_PROP_APPLICATION_NAME,
+                     appName.toLatin1().constData());
+    ca_proplist_sets(props, CA_PROP_APPLICATION_ID,
+                     desktopFile.toLatin1().constData());
+    ca_proplist_sets(props, CA_PROP_CANBERRA_XDG_THEME_NAME,
+                     soundTheme.toLatin1().constData());
+    // We'll also want this cached for a time. volatile makes sure the cache is
+    // dropped after some time or when the cache is under pressure.
+    ca_proplist_sets(props, CA_PROP_CANBERRA_CACHE_CONTROL, "volatile");
+
+    const int ret =
+        ca_context_play_full(d->canberraContext, 0, props, nullptr, nullptr);
+
+    ca_proplist_destroy(props);
+
+    if (ret != CA_SUCCESS) {
+        qCWarning(NOTIFICATIONMANAGER) << "Failed to play sound" << soundName
+                                       << "with canberra:" << ca_strerror(ret);
+        return;
+    }
+}
+
 #include "moc_notifications.cpp"
