@@ -352,10 +352,6 @@ void runEnvironmentScripts()
 
 void setupPlasmaEnvironment()
 {
-    // Manually disable auto scaling because we are scaling above
-    // otherwise apps that manually opt in for high DPI get auto scaled by the developer AND manually scaled by us
-    qputenv("QT_AUTO_SCREEN_SCALE_FACTOR", "0");
-
     qputenv("KDE_FULL_SESSION", "true");
     qputenv("KDE_SESSION_VERSION", "6");
     qputenv("KDE_SESSION_UID", QByteArray::number(getuid()));
@@ -809,7 +805,7 @@ void playStartupSound()
 
     KNotifyConfig notifyConfig(QStringLiteral("plasma_workspace"), QStringLiteral("startkde"));
     const QString action = notifyConfig.readEntry(QStringLiteral("Action"));
-    if (action.isEmpty() || !action.split(QLatin1Char('|')).contains(QLatin1String("Sound"))) {
+    if (action.isEmpty() || !QStringView(action).split(QLatin1Char('|')).contains(u"Sound")) {
         // no startup sound configured
         return;
     }
